==> jc-1.4.0.tar.gz: soot/toolkits/scalar/ArrayFlowUniverse.h <==
// public class soot.toolkits.scalar.ArrayFlowUniverse

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d3fa9f3e76d843f soot_toolkits_scalar_ArrayFlowUniverse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_
#define _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$refs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$refs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object	_jc_soot_toolkits_scalar_ArrayFlowUniverse$object;

typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable;
typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ArrayFlowUniverse$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_ArrayFlowUniverse$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);
extern jint _jc_soot_toolkits_scalar_ArrayFlowUniverse$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);
extern _jc_object_array *_jc_soot_toolkits_scalar_ArrayFlowUniverse$method$toArray$408321282fd84959(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods	soot_toolkits_scalar_ArrayFlowUniverse;
};

// Vtype
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs {
	_jc_object_array	*elements;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$refs {
    _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs	soot_toolkits_scalar_ArrayFlowUniverse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs	soot_toolkits_scalar_ArrayFlowUniverse;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object {
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype	*vtype;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype _jc_soot_toolkits_scalar_ArrayFlowUniverse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ArrayFlowUniverse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ArrayFlowUniverse$class_object;

#endif	/* _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/ArrayFlowUniverse.h <==
// public class soot.toolkits.scalar.ArrayFlowUniverse

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d3fa9f3e76d843f soot_toolkits_scalar_ArrayFlowUniverse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_
#define _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$refs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$refs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs	_jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object	_jc_soot_toolkits_scalar_ArrayFlowUniverse$object;

typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable;
typedef const struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ArrayFlowUniverse$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_ArrayFlowUniverse$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_ArrayFlowUniverse$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_soot_toolkits_scalar_ArrayFlowUniverse$method$toArray$408321282fd84959(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_toolkits_scalar_ArrayFlowUniverse$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vmethods	soot_toolkits_scalar_ArrayFlowUniverse;
};

// Vtype
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs {
	_jc_object_array	*elements;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$refs {
    _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_refs	soot_toolkits_scalar_ArrayFlowUniverse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_ArrayFlowUniverse$sub_nonrefs	soot_toolkits_scalar_ArrayFlowUniverse;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ArrayFlowUniverse$object {
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype	*vtype;
	_jc_soot_toolkits_scalar_ArrayFlowUniverse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ArrayFlowUniverse$vtype _jc_soot_toolkits_scalar_ArrayFlowUniverse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ArrayFlowUniverse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ArrayFlowUniverse$class_object;

#endif	/* _JC_soot_toolkits_scalar_ArrayFlowUniverse_H_ */
